@@ -25,14 +25,16 @@
 #               0.2.6 | dantezhu | 2013-07-15 16:44:12 | fix bug，当params中有为0的参数时，不正常
 #               0.2.7 | dantezhu | 2013-07-16 01:28:20 | 增加js直接渲染
 #               0.2.8 | dantezhu | 2013-07-16 12:04:23 | 使用encodeURIComponent，否则中文有问题
+#               0.2.9 | dantezhu | 2013-07-16 12:04:23 | 用tojson，支持直接放到html中
 #
 #=============================================================================
 '''
 
-__version__ = (0, 2, 8)
+__version__ = (0, 2, 9)
 
 from flask import Response, Markup
-from flask import render_template_string, json
+from flask import current_app
+from flask import render_template_string
 
 FLASK_UTIL_JS_PATH = '/flask_util.js'
 
@@ -40,7 +42,7 @@ FLASK_UTIL_JS_TPL_STRING = '''
 {% autoescape false %}
 
 var flask_util = function() {
-    var url_map = {{ json_url_map }};
+    var url_map = {{ url_map|tojson }};
 
     function url_for(endpoint, params) {
         if (!params) {
@@ -123,25 +125,8 @@ class FlaskUtilJs(object):
 
         @app.route(path, endpoint=endpoint)
         def flask_util_js():
-            org_url_map = app.url_map._rules_by_endpoint
-
-            #把重的逻辑还是放到python代码里
-            url_map = dict()
-
-            for k,v in org_url_map.items():
-                url_map[k] = dict(
-                    rule=v[0].rule,
-                    )
-
-            json_url_map = json.dumps(url_map, indent=4, ensure_ascii=False)
-
-            rv = render_template_string(
-                FLASK_UTIL_JS_TPL_STRING, 
-                json_url_map=json_url_map
-                )
-
             return Response(
-                rv,
+                self.content,
                 content_type='text/javascript; charset=UTF-8',
                 headers={
                     'Cache-Control':'no-cache',
@@ -160,6 +145,29 @@ class FlaskUtilJs(object):
     def endpoint(self):
         return self._endpoint
 
+    @property
+    def content(self):
+        org_url_map = current_app.url_map._rules_by_endpoint
+
+        #把重的逻辑还是放到python代码里
+        url_map = dict()
+
+        for k,v in org_url_map.items():
+            url_map[k] = dict(
+                rule=v[0].rule,
+                )
+
+        data = render_template_string(
+            FLASK_UTIL_JS_TPL_STRING, 
+            url_map=url_map,
+            )
+
+        return data
+
     @property
     def js(self):
-        return Markup('<script src="%s" type="text/javascript" charset="utf-8"></script>') % self.path
+        return Markup('<script src="%s" type="text/javascript" charset="utf-8"></script>' % self.path)
+
+    @property
+    def html(self):
+        return Markup('<script type="text/javascript" charset="utf-8">%s</script>' % self.content)
